=============
API Reference
=============

This page gives an overview of all bcselector objects and functions.

.. toctree::
   :maxdepth: 2

   variable_selection
   data_generation
   datasets
   information_theory
   filter_methods